MemoryPool

Struct MemoryPool 

pub struct MemoryPool(/* private fields */);
Available on crate features dcre and unstable only.
An owned memory pool.

Deletes the memory pool automatically when dropped. The destructor will panic if the deletion fails.

Implementations

Source

impl MemoryPool

pub fn build() -> Builder<__block_size_is_not_specified__, __block_count_is_not_specified__>

acre_mpf: Create a builder for MemoryPool.

Examples
use itron::memorypool::MemoryPool;
let pool = MemoryPool::build()
    .block_size(32)
    .block_count(4)
    .finish()
    .expect("failed to create a memory pool");

let block = pool.as_ref().get()
   .expect("failed to allocate a block");
pool.as_ref().release(block)
   .expect("failed to deallocate a block");
Source

impl MemoryPool

pub const unsafe fn from_raw_nonnull(id: NonNullID) -> Self

Construct a MemoryPool from a raw object ID.

Safety

See Object ID Wrappers.

pub const fn leak<'a>(self) -> MemoryPoolRef<'a>

Consume and “leak” self, returning a reference MemoryPoolRef<'a>.

pub const fn as_raw(&self) -> ID

Get the raw object ID.

pub const fn as_raw_nonnull(&self) -> NonNullID

Get the raw object ID as abi::NonNullID.

pub const fn as_ref(&self) -> MemoryPoolRef<'_>

Borrow MemoryPool as MemoryPoolRef.

Use this to perform operations on memory pools because most of the methods are implemented on MemoryPoolRef but not MemoryPool.