MigrateError

Enum MigrateError 

pub enum MigrateError {
    BadContext(MaybeKind),
    BadId(MaybeKind),
    BadParam(MaybeKind),
    AccessDenied(MaybeKind),
}
Available on crate feature unstable only.
Error type for TaskRef::migrate.

This type is an error kind type.

Variants



BadContext(MaybeKind)

Requires: cfg(any(feature = "fmp3", feature = "solid_fmp3"))



BadId(MaybeKind)

Requires: cfg(any(feature = "fmp3", feature = "solid_fmp3"))



BadParam(MaybeKind)

Bad parameter.

  • The task is a restricted task, for which migration is not supported (E_NOSPT, NGKI1186).

  • The class the task belongs to does not permit assigning tasks to the specified processor (E_PAR, NGKI1160).

  • The task belongs to a processs that is different from the calling processor (E_OBJ, NGK1157).

Requires: cfg(any(feature = "fmp3", feature = "solid_fmp3"))



AccessDenied(MaybeKind)

Requires: cfg(any())