Current

Struct Current 

pub struct Current { /* private fields */ }
Available on crate feature unstable only.
Represents a reference to the current task. Returned by current.

This type is !Send, so it cannot be sent to other threads. This ensures any TaskRefs created from this type do not outlive the referenced task.

Implementations

Source

impl Current

pub const fn as_raw(&self) -> ID

Get the raw object ID.

pub const fn as_raw_nonnull(&self) -> NonNullID

Get the raw object ID as abi::NonNullID.

pub const fn as_ref(&self) -> TaskRef<'_>

Borrow Current as TaskRef.

Use this to perform operations on tasks because most of the methods are implemented on TaskRef but not Current.