pub struct Current { /* private fields */ }Available on crate feature
unstable only.Expand description
Represents a reference to the current task. Returned by current.
This type is !Send, so it cannot be sent to other threads. This ensures
any TaskRefs created from this type do not outlive the referenced task.
Implementations
Sourceimpl Current
impl Current
Sourcepub const fn as_raw_nonnull(&self) -> NonNullID
pub const fn as_raw_nonnull(&self) -> NonNullID
Get the raw object ID as abi::NonNullID.